=======================
Simple GraphQL Client
=======================

.. automodule:: sgqlc
    :noindex:

Table of Contents
==================

.. toctree::

   sgqlc
   sgqlc.codegen
   sgqlc.types
   sgqlc.types.datetime
   sgqlc.types.relay
   sgqlc.types.uuid
   sgqlc.operation
   sgqlc.endpoint
   sgqlc.endpoint.base
   sgqlc.endpoint.http
   sgqlc.endpoint.requests
   sgqlc.endpoint.websocket
   sgqlc.introspection


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

:license: ISC
